@@ -19,6 +19,7 @@ from caldav.objects import log
 from caldav.objects import Principal
 from caldav.objects import ScheduleInbox
 from caldav.objects import ScheduleOutbox
+from caldav.requests import HTTPBearerAuth
 from lxml import etree
 
 if six.PY3:
@@ -322,6 +323,7 @@ class DAVClient:
         username=None,
         password=None,
         auth=None,
+        timeout=None,
         ssl_verify_cert=True,
         ssl_cert=None,
     ):
@@ -331,7 +333,7 @@ class DAVClient:
          * url: A fully qualified url: `scheme://user:pass@hostname:port`
          * proxy: A string defining a proxy server: `hostname:port`
          * username and password should be passed as arguments or in the URL
-         * auth and ssl_verify_cert is passed to requests.request.
+         * auth, timeout and ssl_verify_cert are passed to requests.request.
          ** ssl_verify_cert can be the path of a CA-bundle or False.
 
         The requests library will honor a .netrc-file, if such a file exists
@@ -377,6 +379,7 @@ class DAVClient:
         self.auth = auth
         # TODO: it's possible to force through a specific auth method here,
         # but no test code for this.
+        self.timeout = timeout
         self.ssl_verify_cert = ssl_verify_cert
         self.ssl_cert = ssl_cert
         self.url = self.url.unauth()
@@ -584,6 +587,7 @@ class DAVClient:
                 headers=combined_headers,
                 proxies=proxies,
                 auth=self.auth,
+                timeout=self.timeout,
                 verify=self.ssl_verify_cert,
                 cert=self.ssl_cert,
             )
@@ -601,25 +605,22 @@ class DAVClient:
                 url=str(url),
                 headers=combined_headers,
                 proxies=proxies,
+                timeout=self.timeout,
                 verify=self.ssl_verify_cert,
                 cert=self.ssl_cert,
             )
             if not r.status_code == 401:
                 raise
 
-        if (
-            r.status_code == 401
-            and "WWW-Authenticate" in r.headers
-            and self.password
-            and self.username
-            and not self.auth
-        ):
+        if r.status_code == 401 and "WWW-Authenticate" in r.headers and not self.auth:
             auth_types = self.extract_auth_types(r.headers["WWW-Authenticate"])
 
-            if "basic" in auth_types:
-                self.auth = requests.auth.HTTPBasicAuth(self.username, self.password)
-            elif "digest" in auth_types:
+            if self.password and self.username and "digest" in auth_types:
                 self.auth = requests.auth.HTTPDigestAuth(self.username, self.password)
+            elif self.password and self.username and "basic" in auth_types:
+                self.auth = requests.auth.HTTPBasicAuth(self.username, self.password)
+            elif self.password and "bearer" in auth_types:
+                self.auth = HTTPBearerAuth(self.password)
             else:
                 raise NotImplementedError(
                     "The server does not provide any of the currently "
@@ -628,13 +629,7 @@ class DAVClient:
 
             return self.request(url, method, body, headers)
 
-        elif (
-            r.status_code == 401
-            and "WWW-Authenticate" in r.headers
-            and self.password
-            and self.username
-            and self.auth
-        ):
+        elif r.status_code == 401 and "WWW-Authenticate" in r.headers and self.auth:
 
             ## Some (ancient) servers don't like UTF-8 binary auth with Digest authentication.
             ## An example are old SabreDAV based servers.  Not sure about UTF-8 and Basic Auth,
@@ -643,15 +638,17 @@ class DAVClient:
 
             auth_types = self.extract_auth_types(r.headers["WWW-Authenticate"])
 
-            if hasattr(self.password, "decode"):
-                if "basic" in auth_types:
-                    self.auth = requests.auth.HTTPBasicAuth(
-                        self.username, self.password.decode()
-                    )
-                elif "digest" in auth_types:
+            if self.password and hasattr(self.password, "decode"):
+                if self.username and "digest" in auth_types:
                     self.auth = requests.auth.HTTPDigestAuth(
                         self.username, self.password.decode()
                     )
+                elif self.username and "basic" in auth_types:
+                    self.auth = requests.auth.HTTPBasicAuth(
+                        self.username, self.password.decode()
+                    )
+                elif "bearer" in auth_types:
+                    self.auth = HTTPBearerAuth(self.password.decode())
 
             self.username = None
             self.password = None
