@@ -78,8 +78,11 @@ incompatibility_description = {
         """RFC6578 is not supported, things will break if we try to do a sync-token report""",
 
     'time_based_sync_tokens':
-        """The sync token is typically a time stamp, and we need to sleep a """
-        """second in the test code to get things right""",
+        """A sync-token report depends on the unix timestamp, """
+        """several syncs on the same second may cause problems, """
+        """so we need to sleep a bit. """
+        """(this is a neligible problem if sync returns too much, but may be """
+        """disasterously if it returns too little). """,
 
     'fragile_sync_tokens':
         """Every now and then (or perhaps always), more content than expected """
@@ -152,7 +155,7 @@ incompatibility_description = {
         """Searching for 'CONF' i.e. in the class field will not yield CONFIDENTIAL.  Which generally makes sense, but the RFC specifies substring match""",
 
     'text_search_is_exact_match_sometimes':
-        """Some servers are doing an exact match on summary field but substring match on category""",
+        """Some servers are doing an exact match on summary field but substring match on category or vice versa""",
 
    'combined_search_not_working':
         """When querying for a text match and a date range in the same report, weird things happen""",
@@ -183,6 +186,12 @@ incompatibility_description = {
 
     'no_relships':
         """The calendar server does not support child/parent relationships between calendar components""",
+
+    'isnotdefined_not_working':
+        """The is-not-defined in a calendar-query not working as it should - see https://gitlab.com/davical-project/davical/-/issues/281""",
+
+    'search_needs_comptype':
+        """The server may not always come up with anything useful when searching for objects and ommitting to specify weather one wants to see tasks or events""",
 }
 
 xandikos = [
@@ -210,14 +219,10 @@ radicale = [
     ## TODO: raise an issue on this one
     "radicale_breaks_on_category_search",
 
-    ## Expanding recurrent events is not yet supported
-    ## ref https://github.com/Kozea/Radicale/issues/662
-    "no_recurring_expandation",
-
     'no_scheduling',
 
     'text_search_is_case_insensitive',
-    'text_search_is_exact_match_only',
+    'text_search_is_exact_match_sometimes',
     'combined_search_not_working',
 
     ## extra features not specified in RFC5545
@@ -249,6 +254,7 @@ zimbra = [
     'category_search_yields_nothing',
     'text_search_is_exact_match_only',
     'no_relships',
+    'isnotdefined_not_working',
 
     ## extra features not specified in RFC5545
     "calendar_order",
@@ -301,10 +307,13 @@ icloud = [
 ]
 
 davical = [
+    #'no_journal', ## it threw a 500 internal server error! ## for old versions
     #'nofreebusy', ## for old versions
-    'fragile_sync_tokens',
-    'no_journal', ## it threw a 500 internal server error!
-    'vtodo_datesearch_nodtstart_task_is_skipped_in_closed_date_range',
+    'fragile_sync_tokens', ## no issue raised yet
+    'vtodo_datesearch_nodtstart_task_is_skipped_in_closed_date_range', ## no issue raised yet
+    'isnotdefined_not_working', ## https://gitlab.com/davical-project/davical/-/issues/281
+    'fastmail_buggy_noexpand_date_search', ## https://gitlab.com/davical-project/davical/-/issues/280
+    "isnotdefined_not_working",
 ]
 
 google = [
@@ -314,11 +323,19 @@ google = [
     'no_recurring_expandation'
 ]
 
-sogo = [
+## https://www.sogo.nu/bugs/view.php?id=3065
+## left a note about time-based sync tokens on https://www.sogo.nu/bugs/view.php?id=5163
+## https://www.sogo.nu/bugs/view.php?id=5282
+## https://bugs.sogo.nu/view.php?id=5693
+## https://bugs.sogo.nu/view.php?id=5694
+sogo = [ ## and in addition ... the requests are efficiently rate limited, as it spawns lots of postgresql connections all until it hits a limit, after that it's 501 errors ...
+    "time_based_sync_tokens",
+    "search_needs_comptype",
+    "fastmail_buggy_noexpand_date_search",
+    "text_search_not_working",
+    "isnotdefined_not_working",
     'no_journal',
-    'no_freebusy_rfc4791', ## https://www.sogo.nu/bugs/view.php?id=5282
-    "time_based_sync_tokens", ## Left a note on https://www.sogo.nu/bugs/view.php?id=5163
-    "no_expand", ## https://www.sogo.nu/bugs/view.php?id=3065
+    'no_freebusy_rfc4791'
 ]
 
 nextcloud = [
@@ -337,7 +354,8 @@ fastmail = [
     'fastmail_buggy_noexpand_date_search',
     'combined_search_not_working',
     'text_search_is_exact_match_sometimes',
-    'rrule_takes_no_count'
+    'rrule_takes_no_count',
+    'isnotdefined_not_working',
 ]
 
 synology = [
@@ -355,7 +373,8 @@ robur = [
     'no_freebusy_rfc4791',
     'no_todo_datesearch', ## returns nothing
     'text_search_not_working',
-    'no_relships'
+    'no_relships',
+    'isnotdefined_not_working',
 ]
 
 
